@@ -8,8 +8,8 @@
 """
 
 __all__ = ["MokeError", "task", "stdin", "stdout", "stderr", "num", "doc",
-           "INFO", "WARN", "ERROR"]
-__version__ = "1.1.2"
+           "INFO", "WARN", "ERROR", "required"]
+__version__ = "1.1.4"
 
 
 import os
@@ -26,9 +26,13 @@ from ConfigParser import SafeConfigParser
 
 
 # do not remove, really
-from logging import INFO, WARN, ERROR #@UnusedImport
-from sys import stdin, stdout, stderr #@UnusedImport
+from logging import INFO, WARN, ERROR
+from sys import stdin, stdout, stderr
 
+class RequiredArgument(object):
+    pass
+
+required = RequiredArgument
 
 __deflog__ = {"ls":stderr, # log stream
               "ll":"info", # log level
@@ -181,14 +185,14 @@ class task(object):
                     docline = line.replace("-", "", 1).replace(arg, "", 1).strip()
                     argtype, nargs = cls._parsetype(line)
                 except TypeError:
-                        pass
+                    pass
                 break # only the first match
         return docline, argtype, nargs
 
     @classmethod
-    def _funcparse(cls):
+    def _funcparse(cls, doc):
         # parses gathered functions
-        main_parser = ArgumentParser()
+        main_parser = ArgumentParser(description=doc)
 
         # global options
         defcfg = sys.argv[0].replace(".py", ".ini")
@@ -259,11 +263,15 @@ class task(object):
                                                  default=deft, help=docline)
                 else:
                     # function signature > docs string
-                    if deft is not None:
-                        argtype = type(deft)
-                    if argtype is BaseFileType:
-                        # stdin, stdout or an open file
-                        argtype = eval("file_" + deft.mode[0])
+                    if type(deft) == type and issubclass(deft, RequiredArgument):
+                        pass
+                    else:
+                        arg = "-" + arg
+                        if deft is not None:
+                            argtype = type(deft)
+                        if argtype is BaseFileType:
+                            # stdin, stdout or an open file
+                            argtype = eval("file_" + deft.mode[0])
 
                     # default = most types
                     argname = argtype.__name__
@@ -273,8 +281,9 @@ class task(object):
                     if docline:
                         # (XXX) [default: YYY] CONTENT, (XXX) CONTENT, CONTENT
                         argdoc += docline.split(")")[-1].split("]")[-1].strip()
-                    task_parser.add_argument("-" + arg, type=argtype, \
+                    task_parser.add_argument(arg, type=argtype, \
                                         nargs=nargs, default=deft, help=argdoc)
+            
             for arg in required:
                 docline, argtype, nargs = cls._parsearg(arglines, arg)
                 argdoc = "(%s) " % argtype.__name__
@@ -337,9 +346,9 @@ class task(object):
         return func(**args)
 
     @classmethod
-    def _call(cls):
+    def _call(cls, doc):
         # calls the selected function with the parsed arguments
-        parser = cls._funcparse()
+        parser = cls._funcparse(doc)
         try:
             args = dict(parser.parse_args().__dict__)
         except Exception, e:
@@ -348,14 +357,13 @@ class task(object):
         return retval
 
     def __init__(self, func=None):
-
         # gather functions or call selected sub-command
         if inspect.isfunction(func):
             self.__name = func.__name__
             self.__funcs[self.__name] = func
         elif self.__funcs:
             # file contains some functions
-            self._call()
+            self._call(func)
 
     def __call__(self, *args, **kwargs):
         return self.__funcs[self.__name](*args, **kwargs)
